@@ -18,10 +18,10 @@
 #include "containermimedata.h"
 #include "vocabularymimedata.h"
 
-#include <keduvocdocument.h>
-#include <keduvoclesson.h>
-#include <keduvocwordtype.h>
-#include <keduvocexpression.h>
+#include <KEduVocDocument>
+#include <KEduVocLesson>
+#include <KEduVocWordtype>
+#include <KEduVocExpression>
 
 #include <QDebug>
 #include <KLocalizedString>
