@@ -17,7 +17,7 @@
 
 #include "abstractwidget.h"
 
-#include <QtCore/QVariant>
+#include <QVariant>
 
 
 namespace Ui
@@ -35,35 +35,35 @@ class FlashCardModeWidget: public AbstractModeWidget
     Q_OBJECT
 
 public:
-    FlashCardModeWidget(GuiFrontend *frontend, QWidget *parent = 0);
-    virtual QVariant userInput();
+    explicit FlashCardModeWidget(GuiFrontend *frontend, QWidget *parent = 0);
+    QVariant userInput() Q_DECL_OVERRIDE;
 
-    virtual void setQuestion(const QVariant& question);
-    virtual void setSolution(const QVariant& solution);
-    virtual void setQuestionFont(const QFont& font);
-    virtual void setSolutionFont(const QFont& font);
-    virtual void setHint(const QVariant& hint);
-    virtual void setFeedback(const QVariant& feedback) {
+    void setQuestion(const QVariant& question) Q_DECL_OVERRIDE;
+    void setSolution(const QVariant& solution) Q_DECL_OVERRIDE;
+    void setQuestionFont(const QFont& font) Q_DECL_OVERRIDE;
+    void setSolutionFont(const QFont& font) Q_DECL_OVERRIDE;
+    void setHint(const QVariant& hint) Q_DECL_OVERRIDE;
+    void setFeedback(const QVariant& feedback) Q_DECL_OVERRIDE {
         Q_UNUSED(feedback);
     }
-    virtual void setFeedbackState(AbstractFrontend::ResultState feedbackState) {
+    void setFeedbackState(AbstractFrontend::ResultState feedbackState) Q_DECL_OVERRIDE {
         Q_UNUSED(feedbackState);
     }
-    virtual void setResultState(AbstractFrontend::ResultState resultState) {
+    void setResultState(AbstractFrontend::ResultState resultState) Q_DECL_OVERRIDE {
         Q_UNUSED(resultState);
     }
 
-    virtual void setQuestionSound(const QUrl& soundUrl);
-    virtual void setSolutionSound(const QUrl& soundUrl);
-    virtual void setSolutionPronunciation(const QString& pronunciationText);
-    virtual void setQuestionPronunciation(const QString& pronunciationText);
+    void setQuestionSound(const QUrl& soundUrl) Q_DECL_OVERRIDE;
+    void setSolutionSound(const QUrl& soundUrl) Q_DECL_OVERRIDE;
+    void setSolutionPronunciation(const QString& pronunciationText) Q_DECL_OVERRIDE;
+    void setQuestionPronunciation(const QString& pronunciationText) Q_DECL_OVERRIDE;
 
-    virtual void setSynonym(const QString& entry);
+    void setSynonym(const QString& entry) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
-    virtual void showQuestion();
-    virtual void showSolution();
-    virtual void showSynonym();
+    void showQuestion() Q_DECL_OVERRIDE;
+    void showSolution() Q_DECL_OVERRIDE;
+    void showSynonym() Q_DECL_OVERRIDE;
 
 private:
     Ui::FlashCardPracticeWidget* m_ui;
